#include <iostream>

template <typename Type>
class Array {

    const size_t rows;
    const size_t cols;

    Type** elems = nullptr;

public:

    Array(size_t, size_t);
    ~Array();

    void Fill(std::istream&);
    int GetRowSum(size_t) const;

    size_t GetRowNum() const;
    size_t GetColNum() const;
};

template <typename Type>
Array <Type> ::Array(size_t row_num, size_t col_num)
    : rows(row_num), cols(col_num)
{
    if(row_num < 1 || col_num < 1)
        throw std::logic_error("row_num or col_num is 0\n");

    this->elems = new Type*[this->rows];
    
    for(int i = 0; i < this->rows; ++i)
    {
        this->elems[i] = new Type[this->cols];
    }
}

template <typename Type>
void Array <Type> ::Fill(std::istream& istrm)
{
    for(int i = 0; i < this->rows; ++i)
    {
        for(int j = 0; j < this->cols; ++j)
        {
            istrm >> this->elems[i][j];
        }
    }
}

template <typename Type>
int Array <Type> ::GetRowSum(size_t idx) const
{
    if(idx > this->rows)
        throw std::logic_error("idx > row_num\n");

    int sum = 0;
    for(int i = 0; i < this->cols; ++i)
    {
        sum += this->elems[idx][i];
    }

    return sum;
}

template <typename Type>
size_t Array <Type> ::GetRowNum() const
{
    return this->rows;
}

template <typename Type>
size_t Array <Type> ::GetColNum() const
{
    return this->cols;
}

template <typename Type>
Array <Type> ::~Array()
{
    for(int i = 0; i < this->rows; ++i)
    {
        delete [] this->elems[i];
    }

    delete [] this->elems;
}


int main()
{
    size_t nrows, ncols;
    std::cin >> nrows >> ncols;

    Array <int> arr(nrows, ncols);
    arr.Fill(std::cin);

    std::pair <size_t, int> max = { 0, arr.GetRowSum(0) };
    for(int i = 1; i < arr.GetRowNum(); ++i)
    {
        if(auto sum = arr.GetRowSum(i) ; sum > max.second)
        {
            max = { i, sum };
        }
    }

    std::cout << "Max sum in row " << max.first << " is " << max.second << std::endl;

    return 0;
}
